@@ -23,8 +23,8 @@ import markdown as md
 import numpy as np
 from astropy.time import Time
 
-FINK_URL = "http://134.158.75.151:24000"
-COLUMNS = 'i:candid,d:rfscore,i:ra,i:dec,i:jd,i:magpsf,i:objectId,d:cdsxmatch'
+FINK_URL = "https://fink-portal.org"
+COLUMNS = 'i:candid,d:rf_snia_vs_nonia,i:ra,i:dec,i:jd,i:magpsf,i:objectId,d:cdsxmatch'
 
 
 class FinkQueryForm(GenericQueryForm):
@@ -379,5 +379,5 @@ class FinkBroker(GenericBroker):
             ra=alert['i:ra'],
             dec=alert['i:dec'],
             mag=alert['i:magpsf'],
-            score=alert['d:rfscore']
+            score=alert['d:rf_snia_vs_nonia']
         )
